TerraStringExtension class

Constructors

TerraStringExtension()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

containsIgnoreCase(String source, String verify) → bool
escapeSingleQuotes(String str) → String
Remove any Escape symbols from the String
getBase64FromBytes(List<int> data) → String
getBase64FromString(String text) → String
Converts to Base64
getBytesFromBase64(String input) → List<int>
getBytesFromString(String input) → List<int>
Get bytes from String.
getISODateTimeFromString(String dateTime) → DateTime
getISOStringFromDate(DateTime date) → String
getRandomString(int length) → String
getStringFromBase64(String input) → String
getStringFromBytes(List<int> data) → String
getStringOrDefault(String result, {String defaultString = "Unknown"}) → String
Return either the attribute String or a default value.
hexToByteArray(String hex) → List<int>
toStringHex(List<int> bytes) → String